#!/usr/bin/env python

from sklearn.metrics.pairwise import haversine_distances
import numpy as np

class Waypoint:
    def dms2dd(coordinate : str):
        split = coordinate.split('.')
        if 4 != len(split):
            return 0.0

        direction = split[0][1]
        degrees = float(split[0][1:])
        minutes = float(split[1])
        seconds = float(split[2]) * (float(split[3]) / 1000.0)

        dd = degrees + minutes / 60.0 + seconds / (60 * 60)
        if 'E' == direction or 'S' == direction:
            dd *= -1.0

        return dd

    def __init__(self, name : str, latitude : float, longitude : float):
        self.name = name
        self.coordinate = np.array([ latitude, longitude ])

    def __str__(self):
        return 'Name: ' + self.name + ', Lat: ' + str(self.coordinate[0]) + ', Lon: ' + str(self.coordinate[1])

    def haversine(self, other):
        self_radians = [np.radians(_) for _ in self.coordinate]
        other_radians = [np.radians(_) for _ in other.coordinate]
        return 6371.0 * haversine_distances([self_radians, other_radians])[0][1]
